import type { User } from "oidc-client-ts";
import { ComputedRef, type InjectionKey } from "vue";
/**
 * The auth state which, when combined with the auth methods, make up the return object of the `useAuth` hook.
 *
 * @public
 */
export interface AuthState {
    /**
     * See [User](https://authts.github.io/oidc-client-ts/classes/User.html) for more details.
     */
    user?: User | null;
    /**
     * True when the library has been initialized and no navigator request is in progress.
     */
    isLoading: boolean;
    /**
     * True while the user has a valid access token.
     */
    isAuthenticated: boolean;
    /**
     * Tracks the status of most recent signin/signout request method.
     */
    activeNavigator?: "signinRedirect" | "signinPopup" | "signinSilent" | "signoutRedirect" | "signoutPopup";
    /**
     * Was there a signin or silent renew error?
     */
    error?: Error;
}
declare type Action = {
    type: "INITIALISED" | "USER_LOADED";
    user: User | null;
} | {
    type: "USER_UNLOADED";
} | {
    type: "NAVIGATOR_INIT";
    method: NonNullable<AuthState["activeNavigator"]>;
} | {
    type: "NAVIGATOR_CLOSE";
} | {
    type: "ERROR";
    error: Error;
};
export interface AuthStateComputedRefs {
    readonly user: ComputedRef<AuthState["user"]>;
    readonly isLoading: ComputedRef<AuthState["isLoading"]>;
    readonly isAuthenticated: ComputedRef<AuthState["isAuthenticated"]>;
    readonly activeNavigator: ComputedRef<AuthState["activeNavigator"]>;
    readonly error: ComputedRef<AuthState["error"]>;
}
export declare const stateComputedRefs: AuthStateComputedRefs;
export declare const useAuthStateReducer: () => readonly [AuthStateComputedRefs, (action: Action) => void];
export declare const auth_state_key: InjectionKey<AuthStateComputedRefs>;
export declare const useAuthStateProvider: (state: AuthStateComputedRefs) => void;
export {};
